=====================================
Spinneret: Twisted Web's Silk Spinner
=====================================

|build|_ |coverage|_

(Spinneret is still young, its API should be considered unstable.)

Spinneret is a collection of higher-level utilities (such as URL routing,
content type negotiation and processing query arguments) to make writing
complex Twisted Web applications far simpler and (hopefully) more fun! It is
designed to easily integrate with existing Twisted Web projects.

For more info `read the docs <http://txspinneret.readthedocs.org>`_.


Contribute
==========

See https://txspinneret.readthedocs.org/en/latest/contributing.html for
information on contributing to Spinneret.

See http://github.com/jonathanj/txspinneret for development.


Installation
============

.. code-block:: console

    $ pip install txspinneret


.. |build| image:: https://travis-ci.org/jonathanj/txspinneret.svg?branch=master
.. _build: https://travis-ci.org/jonathanj/txspinneret

.. |coverage| image:: https://coveralls.io/repos/jonathanj/txspinneret/badge.png?branch=master
.. _coverage: https://coveralls.io/r/jonathanj/txspinneret?branch=master
